// Copyright (c) 2001, Jan Hermanns & Arno Haase
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or
// without modification, are permitted provided that the
// following conditions are met:
//
//   * Redistributions of source code must retain the above
//     copyright notice, this list of conditions and the
//     following disclaimer. 
//   * Redistributions in binary form must reproduce the above
//     copyright notice, this list of conditions and the
//     following disclaimer in the documentation and/or other
//     materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
// CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
// INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
// OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
// STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
// ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

package safejdbc;

import java.sql.ResultSet;
import java.sql.SQLException;

/**
 * ResultSetProcessors are used to specify how a ResultSet should be handled.
 * An implementation of this interface must be provided if one of the query methods
 * of <a href="SQLExecuter.html">SQLExecuter</a> (or, more generally, an implementation
 * of the <a href="SQL.html">SQL</a> interface) is called. The query method first
 * executes the SQL string and then passes the result to the ResultSetProcessor for
 * processing.
 */
public interface ResultSetProcessor {

    public void process(ResultSet rs) throws SQLException;

}
