// Copyright (c) 2001, Jan Hermanns & Arno Haase
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or
// without modification, are permitted provided that the
// following conditions are met:
//
//   * Redistributions of source code must retain the above
//     copyright notice, this list of conditions and the
//     following disclaimer.
//   * Redistributions in binary form must reproduce the above
//     copyright notice, this list of conditions and the
//     following disclaimer in the documentation and/or other
//     materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
// CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
// INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
// OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
// STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
// ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

package safejdbc;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;


/**
 *  This class contains much of the logic used for handling various exceptions
 *  and Throwables correctly and handling ressources accordingly.
 */
class SQLExceptionHelper {

// --------------------------- a t t r i b u t e s ---------------------------

    private boolean _sqlExceptionOccurred = false;

    private SQLException _sqlException = null;


// --------------------------- m e t h o d s ---------------------------------


    boolean isSQLExceptionOccurred () {
        return _sqlExceptionOccurred;
    }


    void sqlExceptionOccurred (SQLException x) {
        if (!isSQLExceptionOccurred ()) {
            _sqlExceptionOccurred = true;
            _sqlException = x;
        }
        else {
            // chaining is performed correctly, the exception is appended to the
            // end of the chain - despite the misleading name :-)
            _sqlException.setNextException (x);
        }
    }


    void processSQLException () throws SQLException {
        if (isSQLExceptionOccurred ()) {
            _sqlExceptionOccurred = false;

            throw _sqlException;
        }
    }


    void rollback (Connection con) {
        try {
            if (con != null) con.rollback ();
        }
        catch (SQLException x) {
            sqlExceptionOccurred (x);
        }
    }


    void close (Statement stmt) {
        try {
            if (stmt != null) stmt.close ();
        }
        catch (SQLException x) {
            sqlExceptionOccurred (x);
        }
    }


    void close (ResultSet rs, Statement stmt) {
        try {
            if (rs != null) rs.close ();
        }
        catch (SQLException x) {
            sqlExceptionOccurred (x);
        }
        finally {
            close (stmt);
        }
    }
}
