// Copyright (c) 2001, Jan Hermanns & Arno Haase
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or
// without modification, are permitted provided that the
// following conditions are met:
//
//   * Redistributions of source code must retain the above
//     copyright notice, this list of conditions and the
//     following disclaimer. 
//   * Redistributions in binary form must reproduce the above
//     copyright notice, this list of conditions and the
//     following disclaimer in the documentation and/or other
//     materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
// CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
// INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
// OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
// STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
// ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

package safejdbc;

import java.util.Properties;

import java.sql.Driver;
import java.sql.Connection;
import java.sql.SQLException;


/**
 * <p>This is an example-implementation and should not be used in
 * real-world-projects, because connections are not cached. This means
 * every call to getConnection() is delegated to the underlying
 * driver. The driver than creates a connection, wich is a very
 * expensive operation.</p>
 */
public class SimpleConProvider implements ConnectionProvider {

    private Driver     _driver;
    private String     _url;
    private Properties _info;

    /**
     * <b>Example:</b><br>    
     * <pre>
     * ConnectionProvider conprovider = new SimpleConProvider
     *       ("hermanns", "password",
     *        "jdbc:db2://192.168.11.10:8400/Test",
     *        "COM.ibm.db2.jdbc.net.DB2Driver");     
     * </pre>
     */
    public SimpleConProvider
        (String user, String password, String url, String drivername)
        throws Exception {

        Properties info = new Properties();

        info.put("user", user);
        info.put("password", password);

        _driver = (Driver)Class.forName(drivername).newInstance();
	_url    = url;
	_info   = info;        
    }

    
    public SimpleConProvider(String url, Properties info, String drivername) 
	throws Exception {
	
	_driver = (Driver)Class.forName(drivername).newInstance();	
	_url    = url;
	_info   = info;

    }


    public Connection getConnection() throws SQLException {
	return _driver.connect(_url, _info);
    }
    
}
