// Copyright (c) 2001, Jan Hermanns & Arno Haase
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or
// without modification, are permitted provided that the
// following conditions are met:
//
//   * Redistributions of source code must retain the above
//     copyright notice, this list of conditions and the
//     following disclaimer.
//   * Redistributions in binary form must reproduce the above
//     copyright notice, this list of conditions and the
//     following disclaimer in the documentation and/or other
//     materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
// CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
// INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
// OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
// STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
// ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

package safejdbc;

import java.sql.SQLException;


/**
 *  All code in a TXCodeBlock is performed within a single transaction. An
 *  implementation of this interface is passed to the <a href="SQLExecuter.html#executeTX">
 *  executeTX</a> method of SQLExecuter. This method initializes the transaction,
 *  then calls the doTransaction method of the TXCodeBlock. Finally, it commits
 *  the transaction or - if an exception occurred - it rolls the transaction back.
 */
public interface TXCodeBlock {

    /**
     *  This method is called by the executeTX method of SQLExecuter. It
     *  contains all operations that are executed in a separate transaction;
     *  the transaction starts immediately before this method is calls, and
     *  it is ended immediately after this method returns.
     *  @param sql is a special implementation of the SQL interface. The methods
     *    of this implementation provide the actual database operations to be
     *    performed in the transaction.
     */
    public void doTransaction (SQL sql) throws SQLException;
}
