// Copyright (c) 2001, Jan Hermanns & Arno Haase
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or
// without modification, are permitted provided that the
// following conditions are met:
//
//   * Redistributions of source code must retain the above
//     copyright notice, this list of conditions and the
//     following disclaimer. 
//   * Redistributions in binary form must reproduce the above
//     copyright notice, this list of conditions and the
//     following disclaimer in the documentation and/or other
//     materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
// CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
// INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
// OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
// STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
// ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

package safejdbc.holder;


/** This class is designed to hold a double. It is useful to pass a double into and out
 *  of a code block such as a ResultSetProcessor or a FillingCommand. For an overview
 *  see the <a href="package-summary.html">package overview</a>.
 */
public class DoubleHolder {

    private double _value;

    public DoubleHolder(double value) {
        setValue(value);
    }

    public double getValue() {
        return _value;
    }

    public void setValue(double value) {
        _value = value;
    }

    public void add (double value) {
        _value += value;
    }

    public void subtract (double value) {
        _value -= value;
    }

    public void multiply (double value) {
        _value *= value;
    }

    public void divide (double value) {
        _value /= value;
    }
}
